@@ -25,6 +25,7 @@
 #include <KPluginFactory>
 #include <KLocalizedString>
 
+#include "shareprovider.h"
 
 K_PLUGIN_FACTORY(KCMTelepathyChatBehaviorConfigFactory, registerPlugin<BehaviorConfig>();)
 K_EXPORT_PLUGIN(KCMTelepathyChatBehaviorConfigFactory("ktp_chat_behavior", "kcm_ktp_chat_behavior"))
@@ -56,6 +57,9 @@ BehaviorConfig::BehaviorConfig(QWidget *parent, const QVariantList& args)
     ui->checkBoxShowOthersTyping->setChecked(m_showOthersTyping);
     connect(ui->checkBoxShowOthersTyping, SIGNAL(toggled(bool)), this, SLOT(onShowOthersTypingChanged(bool)));
 
+    ui->dontLeaveGroupChats->setChecked(m_dontLeaveGroupChats);
+    connect(ui->dontLeaveGroupChats, SIGNAL(toggled(bool)), this, SLOT(onDontLeaveGroupChatsChanged(bool)));
+
     QStringList nicknameCompletionStyles;
     const QString namePlaceholder = ki18nc("Placeholder for contact name in completion suffix selector", "Nickname").toString();
     Q_FOREACH(const QString &suffix, BehaviorConfig::nicknameCompletionSuffixes) {
@@ -64,6 +68,13 @@ BehaviorConfig::BehaviorConfig(QWidget *parent, const QVariantList& args)
     ui->nicknameCompletionStyle->addItems(nicknameCompletionStyles);
     ui->nicknameCompletionStyle->setCurrentIndex(BehaviorConfig::nicknameCompletionSuffixes.indexOf(m_nicknameCompletionSuffix));
     connect(ui->nicknameCompletionStyle, SIGNAL(currentIndexChanged(int)), this, SLOT(onNicknameCompletionStyleChanged(int)));
+
+    QMap<QString, ShareProvider::ShareService> availableShareServices = ShareProvider::availableShareServices();
+    QStringList sharingServicesList = availableShareServices.keys();
+    ui->imageSharingService->addItems(sharingServicesList);
+    QString shareServiceName = availableShareServices.key(static_cast<ShareProvider::ShareService>(m_imageShareServiceType));
+    ui->imageSharingService->setCurrentIndex(sharingServicesList.indexOf(shareServiceName));
+    connect(ui->imageSharingService, SIGNAL(currentIndexChanged(int)), this, SLOT(onImageSharingServiceChanged(int)));
 }
 
 const QStringList BehaviorConfig::nicknameCompletionSuffixes = QStringList()
@@ -83,6 +94,8 @@ void BehaviorConfig::load()
     m_showMeTyping = TextChatConfig::instance()->showMeTyping();
     m_showOthersTyping = TextChatConfig::instance()->showOthersTyping();
     m_nicknameCompletionSuffix = TextChatConfig::instance()->nicknameCompletionSuffix();
+    m_imageShareServiceType = TextChatConfig::instance()->imageShareServiceType();
+    m_dontLeaveGroupChats = TextChatConfig::instance()->dontLeaveGroupChats();
 }
 
 void BehaviorConfig::save()
@@ -92,6 +105,8 @@ void BehaviorConfig::save()
     TextChatConfig::instance()->setShowMeTyping(m_showMeTyping);
     TextChatConfig::instance()->setShowOthersTyping(m_showOthersTyping);
     TextChatConfig::instance()->setNicknameCompletionSuffix(m_nicknameCompletionSuffix);
+    TextChatConfig::instance()->setImageShareServiceName(m_imageShareServiceType);
+    TextChatConfig::instance()->setDontLeaveGroupChats(m_dontLeaveGroupChats);
     TextChatConfig::instance()->sync();
 }
 
@@ -139,3 +154,18 @@ void BehaviorConfig::onNicknameCompletionStyleChanged(int index)
     m_nicknameCompletionSuffix = BehaviorConfig::nicknameCompletionSuffixes[index];
     Q_EMIT changed(true);
 }
+
+void BehaviorConfig::onImageSharingServiceChanged(int index)
+{
+    Q_UNUSED(index);
+    QString imageShareServiceName = ui->imageSharingService->currentText();
+    kDebug() << imageShareServiceName;
+    m_imageShareServiceType = ShareProvider::availableShareServices()[imageShareServiceName];
+    Q_EMIT changed(true);
+}
+
+void BehaviorConfig::onDontLeaveGroupChatsChanged(bool state)
+{
+    m_dontLeaveGroupChats = state;
+    Q_EMIT changed(true);
+}
