@@ -25,6 +25,7 @@
 
 #include "text-chat-config.h"
 
+#include "shareprovider.h"
 
 QMutex TextChatConfig::mutex(QMutex::Recursive);
 
@@ -36,7 +37,9 @@ public:
     int m_scrollbackLength;
     bool m_showMeTyping;
     bool m_showOthersTyping;
+    bool m_dontLeaveGroupChats;
     QString m_nicknameCompletionSuffix;
+    ShareProvider::ShareService m_imageShareServiceType;
 };
 
 
@@ -83,6 +86,10 @@ void TextChatConfig::sync()
 
     behaviorConfig.writeEntry("nicknameCompletionSuffix", d->m_nicknameCompletionSuffix);
 
+    behaviorConfig.writeEntry("imageShareServiceType", static_cast<int>(d->m_imageShareServiceType));
+
+    behaviorConfig.writeEntry("dontLeaveGroupChats", d->m_dontLeaveGroupChats);
+
     behaviorConfig.sync();
 
     mutex.unlock();
@@ -179,6 +186,31 @@ void TextChatConfig::setNicknameCompletionSuffix(const QString &suffix) {
     mutex.unlock();
 }
 
+ShareProvider::ShareService TextChatConfig::imageShareServiceType() const
+{
+    return d->m_imageShareServiceType;
+}
+
+void TextChatConfig::setImageShareServiceName(ShareProvider::ShareService serviceType)
+{
+    mutex.lock();
+    d->m_imageShareServiceType = serviceType;
+    mutex.unlock();
+}
+
+
+bool TextChatConfig::dontLeaveGroupChats() const
+{
+    return d->m_dontLeaveGroupChats;
+}
+
+void TextChatConfig::setDontLeaveGroupChats(bool dontLeaveGroupChats)
+{
+    mutex.lock();
+    d->m_dontLeaveGroupChats = dontLeaveGroupChats;
+    mutex.unlock();
+}
+
 TextChatConfig::TextChatConfig() :
     d(new TextChatConfigPrivate())
 {
@@ -202,6 +234,12 @@ TextChatConfig::TextChatConfig() :
     d->m_showOthersTyping = behaviorConfig.readEntry("showOthersTyping", true);
 
     d->m_nicknameCompletionSuffix = behaviorConfig.readEntry("nicknameCompletionSuffix", ", ");
+
+    d->m_dontLeaveGroupChats = behaviorConfig.readEntry("dontLeaveGroupChats", false);
+
+    // Imgur is the default image sharing service
+    int shareServiceType = behaviorConfig.readEntry("imageShareServiceType", static_cast<int>(ShareProvider::Imgur));
+    d->m_imageShareServiceType = static_cast<ShareProvider::ShareService>(shareServiceType);
 }
 
 
